package com.mortals.xhx.module.sst.feign;

import com.alibaba.fastjson.JSON;
import com.mortals.xhx.common.code.ApiRespCodeEnum;
import com.mortals.xhx.feign.IFeign;
import com.mortals.xhx.feign.base.pdu.SitePdu;
import com.mortals.xhx.feign.rsp.ApiResp;
import com.mortals.xhx.module.sst.pdu.AcceptHandlingPdu;
import com.mortals.xhx.module.sst.pdu.FindHandlingPageReq;
import com.mortals.xhx.module.sst.pdu.SyntheticalMatterQuery;
import com.mortals.xhx.module.sst.pdu.SyntheticalPdu;
import feign.hystrix.FallbackFactory;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

@FeignClient(name = "complex-window-manager", path = "/complex", fallbackFactory =ComplexFeignFallbackFactory.class)
public interface IApiComplexFeign extends IFeign {

    /**
     * 查询字典
     * @param query
     * @return
     */
    @PostMapping(value = "/api/common/queryDict")
    String queryDict(@RequestBody SyntheticalPdu query);

    /**
     * 查询可受理事项
     * @param query
     * @return
     */
    @PostMapping(value = "/api/event-implementation/list")
    String eventList(@RequestBody SyntheticalMatterQuery query);

    /**
     * 查询事项详情
     * @param query
     * @return
     */
    @PostMapping(value = "/api/event-implementation/get-by-id")
    String eventInfo(@RequestBody SyntheticalPdu query);

    /**
     * 查询事项情形
     * @param query
     * @return
     */
    @PostMapping(value = "/api/bus-situation-material/getSituationMaterialTreeByEventIds")
    String getSituationMaterialTreeByEventIds(@RequestBody SyntheticalPdu query);

    /**
     * 根据事项EventId查询办理事项材料
     * @param query
     * @return
     */
    @PostMapping(value = "/api/material/findList")
    String findMaterialList(@RequestBody SyntheticalPdu query);

    /**
     * 根据事项情形查询办理事项材料
     * @param query
     * @return
     */
    @PostMapping(value = "/api/consulting-service/getMaterialByEventAndSituation")
    String getMaterialByEventAndSituation(@RequestBody SyntheticalPdu query);

    /**
     * 获取办件要素
     * @param query
     * @return
     */
    @PostMapping(value = "/api/event-implementation/getDynamicFormByEventIds")
    String getDynamicFormByEventIds(@RequestBody SyntheticalPdu query);

    /**
     * 自助设备接件
     * @param query
     * @return
     */
    @PostMapping(value = "/api/self-device-info/acceptHandling")
    String acceptHandling(@RequestBody AcceptHandlingPdu query);

    /**
     * 查询已受理事项列表
     * @param query
     * @return
     */
    @PostMapping(value = "/api/handling/findPageWithPermission")
    String findPageWithPermission(@RequestBody FindHandlingPageReq query);

    /**
     * 文件下载
     * @param query
     * @return
     */
    @PostMapping(value = "/api/common/downloadFileFtp")
    String downloadFileFtp(@RequestBody FindHandlingPageReq query);

}

@Slf4j
@Component
class ComplexFeignFallbackFactory implements FallbackFactory<IApiComplexFeign> {

    @Override
    public IApiComplexFeign create(Throwable cause) {
        return new IApiComplexFeign(){

            @Override
            public String queryDict(SyntheticalPdu query) {
                ApiResp<String> failResp = new ApiResp<>();
                failResp.setCode(ApiRespCodeEnum.FAILED.getValue());
                failResp.setMsg("暂时无法查询字典，请稍后再试!");
                return JSON.toJSONString(failResp);
            }

            @Override
            public String eventList(SyntheticalMatterQuery query) {
                ApiResp<String> failResp = new ApiResp<>();
                failResp.setCode(ApiRespCodeEnum.FAILED.getValue());
                failResp.setMsg("暂时无法查询可受理事项，请稍后再试!");
                return JSON.toJSONString(failResp);
            }

            @Override
            public String eventInfo(SyntheticalPdu query) {
                ApiResp<String> failResp = new ApiResp<>();
                failResp.setCode(ApiRespCodeEnum.FAILED.getValue());
                failResp.setMsg("暂时无法调用接口，请稍后再试!");
                return JSON.toJSONString(failResp);
            }

            @Override
            public String getSituationMaterialTreeByEventIds(SyntheticalPdu query) {
                ApiResp<String> failResp = new ApiResp<>();
                failResp.setCode(ApiRespCodeEnum.FAILED.getValue());
                failResp.setMsg("暂时无法调用接口，请稍后再试!");
                return JSON.toJSONString(failResp);
            }

            @Override
            public String findMaterialList(SyntheticalPdu query) {
                ApiResp<String> failResp = new ApiResp<>();
                failResp.setCode(ApiRespCodeEnum.FAILED.getValue());
                failResp.setMsg("暂时无法调用接口，请稍后再试!");
                return JSON.toJSONString(failResp);
            }

            @Override
            public String getMaterialByEventAndSituation(SyntheticalPdu query) {
                ApiResp<String> failResp = new ApiResp<>();
                failResp.setCode(ApiRespCodeEnum.FAILED.getValue());
                failResp.setMsg("暂时无法调用接口，请稍后再试!");
                return JSON.toJSONString(failResp);
            }

            @Override
            public String getDynamicFormByEventIds(SyntheticalPdu query) {
                ApiResp<String> failResp = new ApiResp<>();
                failResp.setCode(ApiRespCodeEnum.FAILED.getValue());
                failResp.setMsg("暂时无法调用接口，请稍后再试!");
                return JSON.toJSONString(failResp);
            }

            @Override
            public String acceptHandling(AcceptHandlingPdu query) {
                ApiResp<String> failResp = new ApiResp<>();
                failResp.setCode(ApiRespCodeEnum.FAILED.getValue());
                failResp.setMsg("暂时无法调用接口，请稍后再试!");
                return JSON.toJSONString(failResp);
            }

            @Override
            public String findPageWithPermission(FindHandlingPageReq query) {
                ApiResp<String> failResp = new ApiResp<>();
                failResp.setCode(ApiRespCodeEnum.FAILED.getValue());
                failResp.setMsg("暂时无法调用接口，请稍后再试!");
                return JSON.toJSONString(failResp);
            }

            @Override
            public String downloadFileFtp(FindHandlingPageReq query) {
                ApiResp<String> failResp = new ApiResp<>();
                failResp.setCode(ApiRespCodeEnum.FAILED.getValue());
                failResp.setMsg("暂时无法调用接口，请稍后再试!");
                return JSON.toJSONString(failResp);
            }
        };
    }
}
